@@ -70,4 +70,37 @@ def encode_image_to_bytes(image_array):
     except:
         image_encoded = ''
         status_encoded = False
-    return image_encoded , status_encoded
\ No newline at end of file
+    return image_encoded , status_encoded
+
+
+def draw_label(image_array, 
+                bbox: [int, int, int, int, int], 
+                width: int, 
+                height: int,
+                label_text: str,
+                font_size=2, 
+                font_scale=2,
+                color=(0, 0, 0)): 
+    """[summary]
+
+    Arguments:
+        image_array {numpy array} -- input image
+        bbox {[int, int, int, int]} -- bounding boxes -> [x1, y1, x2, y2]
+        width {int} -- width of label box
+        height {int} -- height of labelbox
+        label_text {str} -- label text
+
+    Keyword Arguments:
+        color {tuple} -- color tuple (default: {(0, 0, 0)})
+
+    Returns:
+        [type] -- [description]
+    """    
+    rad = int(width/8.)
+    img = cv2.rectangle(image_array, (bbox[0], bbox[1]), (bbox[0] + width, bbox[1] - height), color, thickness=-1)
+    img = cv2.rectangle(image_array, (bbox[0] + rad, bbox[1] - height - rad), (bbox[0] + width - rad, bbox[1] - height), color, thickness=-1)
+    img = cv2.circle(img, (bbox[0] + rad, bbox[1] - height), rad, color, -1)
+    img = cv2.circle(img, (bbox[0] + width - rad, bbox[1] - height), rad, color, -1)
+    img = cv2.putText(img, label_text, (bbox[0] + 5, bbox[1] - 5), cv2.FONT_HERSHEY_SIMPLEX ,  
+                   font_size, (255, 255, 255), font_scale, cv2.LINE_AA)
+    return img 
\ No newline at end of file
